@@ -33,12 +33,12 @@
  */
 #define __PRELUDE_HAVE_STDINT_H
 #define __PRELUDE_HAVE_INTTYPES_H
-/* #define __PRELUDE_HAVE_64BIT_LONG */
+#define __PRELUDE_HAVE_64BIT_LONG
 #define __PRELUDE_STDINT_HAVE_UINT8
 #define __PRELUDE_STDINT_HAVE_UINT16
 #define __PRELUDE_STDINT_HAVE_UINT32
 #define __PRELUDE_STDINT_HAVE_UINT64
-#define __PRELUDE_64BIT_FORMAT_PREFIX "ll"
+
 
 #ifdef __PRELUDE_HAVE_64BIT_LONG
  #define __PRELUDE_INT64_SUFFIX(x) x ## L
@@ -60,6 +60,7 @@
 # include <inttypes.h>
 #endif
 
+#include <limits.h>
 
 #ifndef TRUE
 # define TRUE 1
@@ -107,6 +108,25 @@
 #define PRELUDE_UINTMAX_MAX            UINT64_MAX
 
 
+/* 
+ * Tandem NonStop R series and compatible platforms released before
+ * July 2005 support %Ld but not %lld.  
+ */
+# if defined _TNS_R_TARGET
+#  define _LONG_LONG_FORMAT_PREFIX "L"
+# else
+#  define _LONG_LONG_FORMAT_PREFIX "ll"
+# endif
+
+#if PRELUDE_INT64_MAX == LONG_MAX
+# define __PRELUDE_64BIT_FORMAT_PREFIX "l"
+#elif defined _MSC_VER || defined __MINGW32__
+# define __PRELUDE_64BIT_FORMAT_PREFIX "I64"
+#elif 1 && LONG_MAX >> 30 == 1
+# define __PRELUDE_64BIT_FORMAT_PREFIX _LONG_LONG_FORMAT_PREFIX
+#endif
+
+
 
 /*
  * format specifier
